<?php
/**
 * A general drive class for all kind of "drives".
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class BaseDrive extends BaseSimulator {
	// Price of this drive
	private $price      = 0.00;
	// PS-Zahl
	private $horsePower = 0;
	// Anzahl Nocken
	private $numCams    = 0;

	// Konstruktor
	private function __construct ($class) {
		// Call parent constructor
		parent::constructor($class);

		// Debug message
		if (((defined('DEBUG_DRIVE')) || (defined('DEBUG_ALL'))) && (defined('DEBUG_CONSTRUCT'))) {
			$this->getDebugInstance()->output(sprintf("[%s:%d] Konstruktor erreicht.<br />\n",
				__CLASS__,
				__LINE__
			));
		}

		// Set description
		$this->setPartDescr("Namenloser Antrieb");

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removePartInstance();
	}

	/**
	 * Calls the private constructor
	 *
	 * @param	$class	The class' name
	 * @return	void
	 */
	public function constructor ($class) {
		$this->__construct($class);
	}

	// Setter-Methode fuert PS-Zahl
	public final function setHorsePower ($hp) {
		if ((defined('DEBUG_DRIVE')) || (defined('DEBUG_ALL'))) $this->getDebugInstance()->output(sprintf("[%s:%d] Antriebsleistung wird auf <strong>%d</strong> PS gesetzt.<br />\n",
			__CLASS__,
			__LINE__,
			$hp
		));
		$this->horsePower = (int) $hp;
	}

	// Setter-Methode fuer Nockenanzahl
	public final function setNumCams ($cams) {
		if ((defined('DEBUG_DRIVE')) || (defined('DEBUG_ALL'))) $this->getDebugInstance()->output(sprintf("[%s:%d] Nockenanzahl wird auf <strong>%d</strong> Nocken gesetzt.<br />\n",
			__CLASS__,
			__LINE__,
			$cams
		));
		$this->numCams = (int) $cams;
	}

	// Setter for price
	public final function setPrice ($price) {
		$this->price = (float) $price;
	}

	// Getter for price
	public final function getPrice () {
		return $this->price;
	}

	public function removePrice () {
		unset($this->price);
	}
}

// [EOF]
?>
