<?php
/**
 * The control bridge of the ship
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class Bridge extends BaseUpperStructure implements ItemIsTradeable, ConstructableShipPart {
	// Constructor
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Debug message
		if (((defined('DEBUG_MODE')) || (defined('DEBUG_ALL'))) && (defined('DEBUG_CONSTRUCT'))) $this->getDebugInstance()->output(sprintf("[%s:%d] Konstruktor erreicht.<br />\n",
			__CLASS__,
			__LINE__
		));

		// Set description
		$this->setPartDescr("Br&uuml;cke");

		// Generate unique ID number
		$this->createUniqueID();

		// Clean up a little
		$this->removeSystemArray();
		$this->removePartInstance();
	}

	// Eine Kommandobruecke erstellen
	public final static function createBridge ($width, $height, $length) {
		// Get new instance
		$bridgeInstance = new Bridge();

		// Debug message
		if ((defined('DEBUG_MODE')) || (defined('DEBUG_ALL'))) $bridgeInstance->getDebugInstance()->output(sprintf("[%s:%d] Eine Br&uuml;cke wird konstruiert...<br />\n",
			__CLASS__,
			__LINE__
		));

		// Abmasse setzen
		$bridgeInstance->setWidth($width);
		$bridgeInstance->setHeight($height);
		$bridgeInstance->setLength($length);

		// Instanz zurueckgeben
		return $bridgeInstance;
	}

	// Overwritten method for tradeable items
	public function isTradeable () {
		return true;
	}

	/**
	 * Stub!
	 */
	public function saveObjectToDatabase () {
		$this->getDebugInstance()->output(sprintf("[%s:] Stub <strong>%s</strong> erreicht.",
			$this->__toString(),
			__FUNCTION__
		));
	}

	/**
	 * Limits this object with an ObjectLimits instance
	 */
	public function limitObject (ObjectLimits $limitInstance) {
		ApplicationEntryPoint::app_die("".__METHOD__." reached! Stub!");
	}
}

// [EOF]
?>
